@@ -67,7 +67,6 @@ char dec_event_name[DEC_DECODING_TOTAL_EVENT][50] = {
     "DEC_FAKE_EVENT",
     "DEC_SOURCE_CHANGE_EVENT",
     "DEC_PIC_DECODED_EVENT",
-    "DEC_DECODING_FAILED_EVENT",
     "DEC_GOT_EOS_MARK_EVENT",
     "DEC_NO_DECODING_BUFFER_EVENT",
     "DEC_WAIT_DECODING_BUFFER_EVENT",
@@ -497,7 +496,7 @@ void vsi_dec_flush_input_packet(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
 #endif
 
   send_dec_inputbuf_orphan_msg(h->handler, v4l2_msg,
-                               p->dec_cmd.io_buffer.inbufidx);
+                               p->dec_cmd.io_buffer.inbufidx, h->dec_inpkt_flag);
 
   free(p);
   bufferlist_pop_buffer(h->bufferlist_input);
@@ -552,6 +551,7 @@ re_get:
   h->stream_in_mem.mem_type = DWL_MEM_TYPE_SLICE;
 
   h->dec_cur_input_vaddr = virtual_address;
+  h->dec_inpkt_flag = 0;
 
   if (h->secure_mode_on) {
     //The first 16 bytes store bus address of the secure packet data.
@@ -631,6 +631,7 @@ static void vsi_dec_handle_inpkt_cnt(v4l2_dec_inst *h) {
         ASSERT(0);
     } else {
       vsi_dec_send_picconsumed_info(h, p->dec_cmd.io_buffer.inbufidx, INVALID_IOBUFF_IDX);
+      h->dec_inpkt_flag |= ERROR_BUFFER_FLAG;
     }
   }
 
@@ -639,7 +640,9 @@ static void vsi_dec_handle_inpkt_cnt(v4l2_dec_inst *h) {
 
     for (i = 0; i < h->discard_dbp_count; i++) {
       vsi_dec_send_picconsumed_info(h, INVALID_IOBUFF_IDX, INVALID_IOBUFF_IDX);
+#ifdef NXP_TIMESTAMP_MANAGER
       TSManagerSend2(h->tsm, NULL);
+#endif
     }
     h->discard_dbp_count = 0;
   }
@@ -1039,8 +1042,8 @@ v4l2_inst_dec_event vsi_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
     TSManagerValid2(h->tsm, h->consumed_len, NULL);
     HANTRO_LOG(HANTRO_LEVEL_INFO, "consumed len: %d\n", h->consumed_len);
     h->consumed_len = 0;
-  } else if ((event == DEC_DECODING_FAILED_EVENT) &&
-        (h->stream_in_mem.logical_size == 0)) {
+  } else if (event == DEC_DECODING_ERROR_EVENT &&
+             h->stream_in_mem.logical_size == 0) {
     TSManagerValid2(h->tsm, h->consumed_len, NULL);
     TSManagerSend2(h->tsm, NULL);
     HANTRO_LOG(HANTRO_LEVEL_INFO, "broken pic consumed len: %d\n",
@@ -1056,8 +1059,7 @@ v4l2_inst_dec_event vsi_dec_decode(v4l2_dec_inst *h, vsi_v4l2_msg *v4l2_msg) {
     }
   }
 
-  if ((event == DEC_EMPTY_EVENT || event == DEC_DECODING_FAILED_EVENT || 
-      event == DEC_DECODING_ERROR_EVENT) &&
+  if ((event == DEC_EMPTY_EVENT || event == DEC_DECODING_ERROR_EVENT) &&
       vsi_dec_having_input_data(h)) {
     send_fake_cmd(h->handler);
   }
@@ -1200,7 +1202,6 @@ v4l2_inst_dec_event vsi_dec_streaming_output(v4l2_dec_inst *h,
     case DEC_FATAL_ERROR_EVENT:
       break;
 
-    case DEC_DECODING_FAILED_EVENT:
     case DEC_DECODING_ERROR_EVENT:
     case DEC_NO_DECODING_BUFFER_EVENT:
     default:
