@@ -376,6 +376,7 @@ v4l2_inst_dec_event h264_dec_decode(v4l2_dec_inst* h, vsi_v4l2_msg* v4l2_msg) {
   h->dec_aborted = 0;
   do {
     ret = H264DecDecode(dec_inst, &dec_input, &dec_output);
+    h->discard_dbp_count += H264DecDiscardDpbNums(dec_inst);
     HANTRO_LOG(HANTRO_LEVEL_INFO,
                "H264DecDecode ret %d decoded pic %d, out_pid %d\n", ret,
                h->dec_pic_id, h->dec_out_pic_id);
@@ -427,11 +428,9 @@ v4l2_inst_dec_event h264_dec_decode(v4l2_dec_inst* h, vsi_v4l2_msg* v4l2_msg) {
           goto end;
         }
         h->dec_pic_id++;
-#ifdef NXP_TIMESTAMP_MANAGER
         re_dec_event = DEC_PIC_DECODED_EVENT;
         goto update_input;
-#endif
-        break;
+        //break;
 
       case H264DEC_PENDING_FLUSH:
         if (H264DecGetInfo(dec_inst, &dec_info) != H264DEC_OK) {
@@ -454,14 +453,11 @@ v4l2_inst_dec_event h264_dec_decode(v4l2_dec_inst* h, vsi_v4l2_msg* v4l2_msg) {
       case H264DEC_FIELD_DECODED:
         HANTRO_LOG(HANTRO_LEVEL_DEBUG, "Field stream, data left %d\n",
                    dec_output.data_left);
-        h->dec_pic_id++;
         break;
 
       case H264DEC_PIC_CONSUMED:
-#ifdef NXP_TIMESTAMP_MANAGER
-        re_dec_event = DEC_DECODING_FAILED_EVENT;
+        re_dec_event = DEC_DECODING_ERROR_EVENT;
         goto update_input;
-#endif
       case H264DEC_STRM_PROCESSED:
       case H264DEC_NONREF_PIC_SKIPPED:
         break;
@@ -469,7 +465,9 @@ v4l2_inst_dec_event h264_dec_decode(v4l2_dec_inst* h, vsi_v4l2_msg* v4l2_msg) {
       case H264DEC_BUF_EMPTY:
       case H264DEC_STRM_ERROR:
         if (dec_output.data_left == dec_input.data_len) {
+          re_dec_event = DEC_DECODING_ERROR_EVENT;
           in_mem->logical_size = 0;
+          h->consumed_len += dec_input.data_len;
           goto end;
         }
         break;
